
TODO: TODO_06_54_83_58: extend via func instead of delegator

The primary concept for extension may be function (not delegator).

In the past, delegator plugin served as a common module to define related functions,
but that created confusing delegator modules where code for one function is mixed with another.

At this moment, as the first step taken, each func is implemented by its own dedicated delegator -
this separates the concern and removes clutter
(otherwise, the delegator includes logic to decide which of multiple func it handles at the moment).

Next step:
Factor out and simplify code for all dedicated delegators specifically for single func.

NOTE: The task is nearly complete.
Implementing `func` instead of `delegator` may be unnecessary as it does not mean anything more
than current implementation of dedicated 1-to-1 delegators per func.
All what appears missing is simple rename of plugins: Delegator -> Func (and rename does not mean much).
Even if funcs are used as extensions, they (just like delegators) need to provide all the logic for:
*   init_control
*   fill_control
*   search_control
*   invoke_control
*   ...

